((nil . ((whitespace-action auto-cleanup)
	 (whitespace-style face empty trailing lines-tail)
	 (require-final-newline . t)
	 (mode . global-whitespace)))
 (c++-mode . ((c-default-style . "gnu")
	      (indent-tab-mode . t)
	      (tab-width . 8)
	      (fill-column . 70))))
